@@ -26,13 +26,13 @@ class ConfigurablePluginManager(PluginManagerDecorator):
 	derivated object. The file can be used for other purpose by the
 	application using this plugin manager as it will only add a new
 	specific section ``[Plugin Management]`` for itself and also new
-	sections for some plugins that will start with [Plugin:***] (only
-	the plugins that explicitly requires to save configuration options
-	will have this kind of section).
+	sections for some plugins that will start with ``[Plugin:...]``
+	(only the plugins that explicitly requires to save configuration
+	options will have this kind of section).
 
-	*Warning* when giving/building the list of plugins to activate by
-	default, there must not be any space in the list (neither in the
-	names nor in between)
+	.. warning:: when giving/building the list of plugins to activate by
+	    default, there must not be any space in the list (neither in the
+	    names nor in between)
 	"""
 	
 	CONFIG_SECTION_NAME = "Plugin Management"
@@ -199,7 +199,7 @@ class ConfigurablePluginManager(PluginManagerDecorator):
 																		   x)
 		plugin_object.hasConfigOption.__doc__ = self.hasOptionFromPlugin.__doc__
 
-	def activatePluginByName(self, category_name, plugin_name, save_state=True):
+	def activatePluginByName(self, plugin_name, category_name="Default", save_state=True):
 		"""
 		Activate a plugin, , and remember it (in the config file).
 
@@ -215,12 +215,12 @@ class ConfigurablePluginManager(PluginManagerDecorator):
 		argument to False.
 		"""
 		# first decorate the plugin
-		pta = self._component.getPluginByName(category_name,plugin_name)
+		pta = self._component.getPluginByName(plugin_name,category_name)
 		if pta is None:
 			return None
 		self.__decoratePluginObject(category_name,plugin_name,pta.plugin_object)		
 		# activate the plugin
-		plugin_object = self._component.activatePluginByName(category_name,plugin_name)
+		plugin_object = self._component.activatePluginByName(plugin_name,category_name)
 		# check the activation and then optionally set the config option
 		if plugin_object.is_activated:
 			if save_state:
@@ -228,16 +228,16 @@ class ConfigurablePluginManager(PluginManagerDecorator):
 			return plugin_object
 		return None
 
-	def deactivatePluginByName(self, category_name, plugin_name,save_state=True):
+	def deactivatePluginByName(self, plugin_name, category_name="Default", save_state=True):
 		"""
 		Deactivate a plugin, and remember it (in the config file).
 
 		By default, the plugin's deactivation is registered in the
-		config file but if you d'ont want this set the 'save_state'
+		config file but if you d'ont want this set the ``save_state``
 		argument to False.
 		"""
 		# activate the plugin
-		plugin_object = self._component.deactivatePluginByName(category_name,plugin_name)
+		plugin_object = self._component.deactivatePluginByName(plugin_name,category_name)
 		if plugin_object is None:
 			return None
 		# check the deactivation and then optionnally set the config option
@@ -251,7 +251,7 @@ class ConfigurablePluginManager(PluginManagerDecorator):
 		"""
 		Walk through the plugins' places and look for plugins.  Then
 		for each plugin candidate look for its category, load it and
-		stores it in the appropriate slot of the category_mapping.
+		stores it in the appropriate slot of the ``category_mapping``.
 		"""
  		self._component.loadPlugins()
 		# now load the plugins according to the recorded configuration
@@ -269,7 +269,7 @@ class ConfigurablePluginManager(PluginManagerDecorator):
 					# activate all the plugins that should be
 					# activated
 					for plugin_name in plugin_list:
-						self.activatePluginByName(category_name, plugin_name)
+						self.activatePluginByName(plugin_name,category_name)
 
 				
 
