@@ -5,7 +5,7 @@
 The basic interface and implementation for a plugin manager.
 
 Also define the basic mechanism to add functionalities to the base
-PluginManager. A few "principles" to follow in this case:
+PluginManager. A few *principles* to follow in this case:
 
 If the new functionalities do not overlap the ones already
 implemented, then they must be implemented as a Decorator class of the
@@ -43,6 +43,13 @@ class PluginInfo(object):
 		"""
 		Set the namle and path of the plugin as well as the default
 		values for other usefull variables.
+
+		.. warning:: The ``path`` attribute is the full path to the
+		    plugin if it is organised as a directory or the full path
+		    to a file without the ``.py`` extension if the plugin is
+		    defined by a simple file. In the later case, the actual
+		    plugin is reached via ``plugin_info.path+'.py'``.
+			
 		"""
 		self.name = plugin_name
 		self.path = plugin_path
@@ -81,12 +88,12 @@ class PluginManager(object):
 
 	The file describing a plugin should be written in the sytax
 	compatible with Python's ConfigParser module as in the following
-	example:
-	::
+	example::
+	  
 	  [Core Information]
 	  Name= My plugin Name
 	  Module=the_name_of_the_pluginto_load_with_no_py_ending
-       
+         
 	  [Documentation]
 	  Description=What my plugin broadly does
 	  Author= My very own name
@@ -102,9 +109,10 @@ class PluginManager(object):
 		Initialize the mapping of the categories and set the list of
 		directories where plugins may be. This can also be set by
 		direct call the methods: 
-		  - ``setCategoriesFilter`` for ``categories_filter``
-		  - ``setPluginPlaces`` for ``directories_list``
-		  - ``setPluginInfoExtension`` for ``plugin_info_ext``
+		
+		- ``setCategoriesFilter`` for ``categories_filter``
+		- ``setPluginPlaces`` for ``directories_list``
+		- ``setPluginInfoExtension`` for ``plugin_info_ext``
 
 		You may look at these function's documentation for the meaning
 		of each corresponding arguments.
@@ -154,7 +162,7 @@ class PluginManager(object):
 		Set the list of directories where to look for plugin places.
 		"""
 		if directories_list is None:
-			[os.path.dirname(__file__)]
+			directories_list = [os.path.dirname(__file__)]
 		self.plugins_places = directories_list
 
 	def setPluginInfoExtension(self,plugin_info_ext):
@@ -180,6 +188,78 @@ class PluginManager(object):
 		"""
 		return self.category_mapping[category_name]
 
+
+	def _gatherCorePluginInfo(self, directory, filename):
+		"""
+		Gather the core information (name, and module to be loaded)
+		about a plugin described by it's info file (found at
+		'directory/filename').
+
+		Return an instance of ``self.plugin_info_cls`` and the
+		config_parser used to gather the core data *in a tuple*, if the
+		required info could be localised, else return ``(None,None)``.
+		
+		.. note:: This is supposed to be used internally by subclasses
+		    and decorators.
+		
+		"""
+		# now we can consider the file as a serious candidate
+		candidate_infofile = os.path.join(directory,filename)
+		# parse the information file to get info about the plugin
+		config_parser = ConfigParser.SafeConfigParser()
+		try:
+			config_parser.read(candidate_infofile)
+		except:
+			logging.debug("Could not parse the plugin file %s" % candidate_infofile)					
+			return (None, None)
+		# check if the basic info is available
+		if not config_parser.has_section("Core"):
+			logging.debug("Plugin info file has no 'Core' section (in %s)" % candidate_infofile)					
+			return (None, None)
+		if not config_parser.has_option("Core","Name") or not config_parser.has_option("Core","Module"):
+			logging.debug("Plugin info file has no 'Name' or 'Module' section (in %s)" % candidate_infofile)
+			return (None, None)
+		# check that the given name is valid
+		name = config_parser.get("Core", "Name")
+		name = name.strip()
+		if PLUGIN_NAME_FORBIDEN_STRING in name:
+			logging.debug("Plugin name contains forbiden character: %s (in %s)" % (PLUGIN_NAME_FORBIDEN_STRING,
+																				   candidate_infofile))
+			return (None, None)
+		# start collecting essential info
+		plugin_info = self._plugin_info_cls(name, 
+											os.path.join(directory,config_parser.get("Core", "Module")))
+		return (plugin_info,config_parser)
+
+	def gatherBasicPluginInfo(self, directory,filename):
+		"""
+		Gather some basic documentation about the plugin described by
+		it's info file (found at 'directory/filename').
+
+		Return an instance of ``self.plugin_info_cls`` gathering the
+		required informations.
+
+		See also:
+		
+		  ``self._gatherCorePluginInfo``
+		"""
+		plugin_info,config_parser = self._gatherCorePluginInfo(directory, filename)
+		if plugin_info is None:
+			return None
+		# collect additional (but usually quite usefull) information
+		if config_parser.has_section("Documentation"):
+			if config_parser.has_option("Documentation","Author"):
+				plugin_info.author	= config_parser.get("Documentation", "Author")
+			if config_parser.has_option("Documentation","Version"):
+				plugin_info.setVersion(config_parser.get("Documentation", "Version"))
+			if config_parser.has_option("Documentation","Website"): 
+				plugin_info.website	= config_parser.get("Documentation", "Website")
+			if config_parser.has_option("Documentation","Copyright"):
+				plugin_info.copyright	= config_parser.get("Documentation", "Copyright")
+			if config_parser.has_option("Documentation","Description"):
+				plugin_info.description = config_parser.get("Documentation", "Description")
+		return plugin_info
+
 	def locatePlugins(self):
 		"""
 		Walk through the plugins' places and look for plugins.
@@ -201,50 +281,26 @@ class PluginManager(object):
 					# eliminate the obvious non plugin files
 					if not filename.endswith(".%s" % self.plugin_info_ext):
 						continue
-					# now we can consider the file as a serious candidate
 					candidate_infofile = os.path.join(dirpath,filename)
 					logging.debug("""%s found a candidate: 
 	%s""" % (self.__class__.__name__, candidate_infofile))
-					# parse the information file to get info about the plugin
-					config_parser = ConfigParser.SafeConfigParser()
-					try:
-						config_parser.read(candidate_infofile)
-					except:
-						logging.debug("Could not parse the plugin file %s" % candidate_infofile)					
- 						continue
-					# check if the basic info is available
-					if not config_parser.has_section("Core"):
+#					print candidate_infofile
+					plugin_info = self.gatherBasicPluginInfo(dirpath,filename)
+					if plugin_info is None:
+						logging.debug("""Candidate rejected: 
+	%s""" % candidate_infofile)						
 						continue
-					if not config_parser.has_option("Core","Name") or not config_parser.has_option("Core","Module"):
-						continue
-					# check that the given name is valid
-					name = config_parser.get("Core", "Name")
-					name = name.strip()
-					if PLUGIN_NAME_FORBIDEN_STRING in name:
-						continue				
-					# start collecting essential info
-					plugin_info = self._plugin_info_cls(name, 
-														os.path.join(dirpath,config_parser.get("Core", "Module")))
-					# collect additional (but usually quite usefull) information
-					if config_parser.has_section("Documentation"):
-						if config_parser.has_option("Documentation","Author"):
-							plugin_info.author	= config_parser.get("Documentation", "Author")
-						if config_parser.has_option("Documentation","Version"):
-							plugin_info.setVersion(config_parser.get("Documentation", "Version"))
-						if config_parser.has_option("Documentation","Website"): 
-							plugin_info.website	= config_parser.get("Documentation", "Website")
-						if config_parser.has_option("Documentation","Copyright"):
-							plugin_info.copyright	= config_parser.get("Documentation", "Copyright")
-						if config_parser.has_option("Documentation","Description"):
-							plugin_info.description = config_parser.get("Documentation", "Description")
-					
 					# now determine the path of the file to execute,
 					# depending on wether the path indicated is a
 					# directory or a file
+#					print plugin_info.path
 					if os.path.isdir(plugin_info.path):
 						candidate_filepath = os.path.join(plugin_info.path,"__init__")
-					else:
+					elif os.path.isfile(plugin_info.path+".py"):
 						candidate_filepath = plugin_info.path
+					else:
+						continue
+#					print candidate_filepath
 					self._candidates.append((candidate_infofile, candidate_filepath, plugin_info))
 		return len(self._candidates)
 
@@ -253,10 +309,10 @@ class PluginManager(object):
 		Load the candidate plugins that have been identified through a
 		previous call to locatePlugins.  For each plugin candidate
 		look for its category, load it and store it in the appropriate
-		slot of the category_mapping.
+		slot of the ``category_mapping``.
 
 		If a callback function is specified, call it before every load
-		attempt.  The plugin_info instance is passed as an argument to
+		attempt.  The ``plugin_info`` instance is passed as an argument to
 		the callback.
 		"""
 # 		print "%s.loadPlugins" % self.__class__		
@@ -269,16 +325,22 @@ class PluginManager(object):
 			# user
 			if callback is not None:
 				callback(plugin_info)
-
 			# now execute the file and get its content into a
 			# specific dictionnary
 			candidate_globals = {"__file__":candidate_filepath+".py"}
+			if "__init__" in  os.path.basename(candidate_filepath):
+				sys.path.append(plugin_info.path)				
 			try:
 				execfile(candidate_filepath+".py",candidate_globals)
 			except Exception,e:
 				logging.debug("Unable to execute the code in plugin: %s" % candidate_filepath)
 				logging.debug("\t The following problem occured: %s %s " % (os.linesep, e))
-
+				if "__init__" in  os.path.basename(candidate_filepath):
+					sys.path.remove(plugin_info.path)
+				continue
+			
+			if "__init__" in  os.path.basename(candidate_filepath):
+				sys.path.remove(plugin_info.path)
 			# now try to find and initialise the first subclass of the correct plugin interface
 			for element in candidate_globals.values():
 				current_category = None
@@ -316,7 +378,7 @@ class PluginManager(object):
 		self.loadPlugins()
 
 
-	def getPluginByName(self,category,name):
+	def getPluginByName(self,name,category="Default"):
 		"""
 		Get the plugin correspoding to a given category and name
 		"""
@@ -326,11 +388,11 @@ class PluginManager(object):
 					return item
 		return None
 
-	def activatePluginByName(self,category,name):
+	def activatePluginByName(self,name,category="Default"):
 		"""
 		Activate a plugin corresponding to a given category + name.
 		"""
-		pta_item = self.getPluginByName(category,name)
+		pta_item = self.getPluginByName(name,category)
 		if pta_item is not None:
 			plugin_to_activate = pta_item.plugin_object
 			if plugin_to_activate is not None:
@@ -340,7 +402,7 @@ class PluginManager(object):
 		return None
 
 
-	def deactivatePluginByName(self,category,name):
+	def deactivatePluginByName(self,name,category="Default"):
 		"""
 		Desactivate a plugin corresponding to a given category + name.
 		"""
@@ -391,6 +453,11 @@ class PluginManagerDecorator(object):
 
 		  - *If the decorated object is given*, these last arguments are
 		    simply **ignored** !
+
+		All classes (and especially subclasses of this one) that want
+		to be a decorator must accept the decorated manager as an
+		object passed to the init function under the exact keyword
+		``decorated_object``.
 		"""
 		
 		if decorated_object is None:
@@ -426,8 +493,8 @@ class PluginManagerSingleton(object):
 	"""
 	Singleton version of the most basic plugin manager.
 
-	Being a singleton, this class should not be initialised
-	explicitly and the ``get``classmethod must be called instead.
+	Being a singleton, this class should not be initialised explicitly
+	and the ``get`` classmethod must be called instead.
 
 	To call one of this class's methods you have to use the ``get``
 	method in the following way:
@@ -449,9 +516,9 @@ class PluginManagerSingleton(object):
 	def __init__(self):
 		"""
 		Initialisation: this class should not be initialised
-		explicitly and the ``get``classmethod must be called instead.
+		explicitly and the ``get`` classmethod must be called instead.
 
-		To set up the various coonfigurables variables of the
+		To set up the various configurables variables of the
 		PluginManager's behaviour please call explicitly the following
 		methods:
 
@@ -465,7 +532,7 @@ class PluginManagerSingleton(object):
 	def setBehaviour(self,list_of_pmd):
 		"""
 		Set the functionalities handled by the plugin manager by
-		giving a list of PluginManager decorators.
+		giving a list of ``PluginManager`` decorators.
 		
 		This function shouldn't be called several time in a same
 		process, but if it is only the first call will have an effect.
@@ -474,7 +541,7 @@ class PluginManagerSingleton(object):
 		of the singleton.
 
 		In cases where the function is indeed going to change anything
-		the 'True' value is return, in all other cases, the 'False'
+		the ``True`` value is return, in all other cases, the ``False``
 		value is returned.
 		"""
 		if self.__decoration_chain is None and self.__instance is None:
@@ -493,10 +560,12 @@ class PluginManagerSingleton(object):
 		"""
 		if self.__instance is None:
 			if self.__decoration_chain is not None:
-				# Get the obect to be decorated
+				# Get the object to be decorated
+#				print self.__decoration_chain
 				pm = self.__decoration_chain[0]()
 				for cls_item in self.__decoration_chain[1:]:
-					pm = cls_item(pm)
+#					print cls_item
+					pm = cls_item(decorated_manager=pm)
 				# Decorate the whole object
 				self.__instance = pm
 			else:
